@@ -20,7 +20,7 @@
 *****************************************************************************/
 
 #include "qmidictlOptions.h"
-#include "qmidictlUdpDevice.h"
+#include "qmidictlMidiControl.h"
 #include "qmidictlMainForm.h"
 
 #include <QApplication>
@@ -38,6 +38,9 @@ int main ( int argc, char *argv[] )
 		return 1;
 	}
 
+	qmidictlMidiControl ctl;
+	ctl.load(opt.settings());
+
 	qmidictlMainForm w;
 
 	w.show();
